# ---------------------------------------------------------------------------
# 01_Share_Stops_Into_2_Groups.py
# Author: Olivier DRAILY, EC DG REGIO
# Created on: 2020-04-16
#
# Description:
# The script divides a point feature dataset (with stops of all public transport modes) into 2 feature datasets:
#   - one for bus/tram
#   - one for metro/rail
# The criterion used to distinguish both groups of modes of transport is the "route_type" from the General Transit Feed Specification
# See https://developers.google.com/transit/gtfs/reference and https://developers.google.com/transit/gtfs/reference/extended-route-types 
# ---------------------------------------------------------------------------

# Import modules
# ---------------------------------------------------------------------------
import arcpy, os, time
from arcpy import env

print "Start: " + time.strftime("%H:%M:%S", time.localtime())

# Local variables
# ---------------------------------------------------------------------------
input_stops = r"Test.gdb\Test_all_stops_pt"  # Input point feature dataset with bus/tram and metro/rail stop locations
query_bus_tram = "route_type IN (0,3,4,5,6,7,11, 200, 700, 800, 900, 1000, 1200, 1300, 1400)" # Query to select bus/tram stops from the input point feature dataset
query_metro_rail = "route_type IN (1,2, 100, 300, 400, 500, 600)" # Query to select metro/rail stops from the input point feature dataset
out_workspace = r"Test.gdb"  # Output workspace, a geodatabase   #  r"Test.gdb"
area_name = "Test"  # Name of the area to process
bus_tram_dataset_name = area_name + "_bus_tram_pt"
metro_rail_dataset_name = area_name + "_metro_rail_pt"

# Environment
# --------------------------------------------------------------------------- 
arcpy.env.overwriteOutput = True

# Routine printMessage
# ---------------------------------------------------------------------------
def printMessage(msg):
    print msg  # with Python 2.x
    #print(msg)  # with Python 3.x
    arcpy.AddMessage(msg) # in ArcGIS
    
# Main process
# ---------------------------------------------------------------------------
# Make the bus/tram dataset from the input point feature dataset
printMessage("Make the bus/tram dataset")
try:
    arcpy.FeatureClassToFeatureClass_conversion(input_stops, out_workspace, bus_tram_dataset_name, query_bus_tram)
except:
    printMessage("No bus/tram stops in the input dataset, or wrong query")

# Make the metro/rail dataset from the input point feature dataset
printMessage("Make the metro/rail dataset")
try:
    arcpy.FeatureClassToFeatureClass_conversion(input_stops, out_workspace, metro_rail_dataset_name, query_metro_rail)
except:
    printMessage("No metro/rail stops in the input dataset, or wrong query")
    
printMessage("End: " + time.strftime("%H:%M:%S", time.localtime()))
